[cig-commits] [commit] master: Fix a number of text issues. (cacd89c)

cig_noreply at geodynamics.org cig_noreply at geodynamics.org
Mon May 19 13:09:13 PDT 2014


Repository : https://github.com/geodynamics/aspect

On branch  : master
Link       : https://github.com/geodynamics/aspect/compare/8cd10da0b2e753ddd449a2bce24790abdb4af621...3407c2fccc8c98ef3939d3c2d29077b4d899ff4b

>---------------------------------------------------------------

commit cacd89c9899fc990d71b0388e87063cd8b563592
Author: Wolfgang Bangerth <bangerth at math.tamu.edu>
Date:   Mon May 19 14:40:00 2014 -0500

    Fix a number of text issues.


>---------------------------------------------------------------

cacd89c9899fc990d71b0388e87063cd8b563592
 source/postprocess/dynamic_topography.cc               | 15 +++++++++------
 source/postprocess/visualization/dynamic_topography.cc |  9 ++++++---
 2 files changed, 15 insertions(+), 9 deletions(-)

diff --git a/source/postprocess/dynamic_topography.cc b/source/postprocess/dynamic_topography.cc
index a2a1f9c..02b42ca 100644
--- a/source/postprocess/dynamic_topography.cc
+++ b/source/postprocess/dynamic_topography.cc
@@ -138,8 +138,8 @@ namespace aspect
       const double average_topography = Utilities::MPI::sum (integrated_topography,this->get_mpi_communicator()) / Utilities::MPI::sum (integrated_surface_area,this->get_mpi_communicator());
 
 
-      // Write the solution in output file
-      // if (DT_mean_switch == true) susbtract the average dynamic topography,
+      // Write the solution to an output file
+      // if (DT_mean_switch == true) subtract the average dynamic topography,
       // otherwise leave as is
       for (unsigned int i=0; i<stored_values.size(); ++i)
         { 
@@ -256,17 +256,20 @@ namespace aspect
     ASPECT_REGISTER_POSTPROCESSOR(DynamicTopography,
                                   "dynamic topography",
                                   "A postprocessor that computes a measure of dynamic topography "
-                                  "based on the stress at the surface. The data is writte into a "
-                                  "file named 'dynamic_topography.NNNNN' in the output directory, "
+                                  "based on the stress at the surface. The data is written into a "
+                                  "file named 'dynamic\\_topography.NNNNN' in the output directory, "
                                   "where NNNNN is the number of the time step."
                                   "\n\n"
                                   "The exact approach works as follows: At the centers of all cells "
                                   "that sit along the top surface, we evaluate the stress and "
                                   "evaluate the component of it in the direction in which "
                                   "gravity acts. In other words, we compute "
-                                  "$\\sigma_{rr}={\\hat g}^T(2 \\eta \\varepsilon(\\mathbf u))\\hat g$ - \\p "
+                                  "$\\sigma_{rr}={\\hat g}^T(2 \\eta \\varepsilon(\\mathbf u)-\frac 13 (\\textrm{div}\;\\mathbf u)I)\\hat g - p_d$ "
                                   "where $\\hat g = \\mathbf g/\\|\\mathbf g\\|$ is the direction of "
-                                  "the gravity vector $\\mathbf g$. From this, the dynamic "
+                                  "the gravity vector $\\mathbf g$ and $p_d=p-p_a$ is the dynamic "
+                                  "pressure computed by subtracting the adiabatic pressure $p_a$ "
+                                  "from the total pressure $p$ computed as part of the Stokes "
+                                  "solve. From this, the dynamic "
                                   "topography is computed using the formula "
                                   "$h=\\frac{\\sigma_{rr}}{\\|\\mathbf g\\| \\rho}$ where $\\rho$ "
                                   "is the density at the cell center."
diff --git a/source/postprocess/visualization/dynamic_topography.cc b/source/postprocess/visualization/dynamic_topography.cc
index 1f1db46..946b259 100644
--- a/source/postprocess/visualization/dynamic_topography.cc
+++ b/source/postprocess/visualization/dynamic_topography.cc
@@ -98,7 +98,7 @@ namespace aspect
             const Tensor<1,dim> gravity = this->get_gravity_model().gravity_vector(location);
             const Tensor<1,dim> gravity_direction = gravity/gravity.norm();
 
             // Subtract the dynamic presure
             const double dynamic_pressure   = in.pressure[q] - this->get_adiabatic_conditions().pressure(location);
             const double sigma_rr           = gravity_direction * (shear_stress * gravity_direction) - dynamic_pressure;
             const double dynamic_topography = -sigma_rr / gravity.norm() / density;
@@ -125,9 +125,12 @@ namespace aspect
                                                   "dynamic topography requires us to compute the stress tensor and "
                                                   "evaluate the component of it in the direction in which "
                                                   "gravity acts. In other words, we compute "
-                                                  "$\\sigma_{rr}={\\hat g}^T(2 * \\eta \\varepsilon(\\mathbf u))\\hat g - \\p$ "
+                                                  "$\\sigma_{rr}={\\hat g}^T(2 \\eta \\varepsilon(\\mathbf u)-\frac 13 (\\textrm{div}\;\\mathbf u)I)\\hat g - p_d$ "
                                                   "where $\\hat g = \\mathbf g/\\|\\mathbf g\\|$ is the direction of "
-                                                  "the gravity vector $\\mathbf g$. From this, the dynamic "
+                                                  "the gravity vector $\\mathbf g$ and $p_d=p-p_a$ is the dynamic "
+                                                  "pressure computed by subtracting the adiabatic pressure $p_a$ "
+                                                  "from the total pressure $p$ computed as part of the Stokes "
+                                                  "solve. From this, the dynamic "
                                                   "topography is computed using the formula "
                                                   "$h=\\frac{\\sigma_{rr}}{\\|\\mathbf g\\| \\rho}$ where $\\rho$ "
                                                   "is the density at the cell center."
@@ -98,7 +98,7 @@ namespace aspect
             const Tensor<1,dim> gravity_direction = gravity/gravity.norm();
 
-            // Subtract the dynamic presure
+            // subtract the dynamic pressure
             const double dynamic_pressure   = in.pressure[q] - this->get_adiabatic_conditions().pressure(location);
             const double sigma_rr           = gravity_direction * (shear_stress * gravity_direction) - dynamic_pressure;



More information about the CIG-COMMITS mailing list